@@ -44,6 +44,7 @@ except ImportError:
     # < 3.0
     from ConfigParser import NoOptionError, NoSectionError, SafeConfigParser
 import subprocess
+from collections import defaultdict
 
 from germinate.germinator import Germinator
 import germinate.archive
@@ -150,6 +151,10 @@ def main(argv):
         seed_dist = config.get(dist, 'seed_dist')
     else:
         seed_dist = dist
+    if config.has_option(dist, 'dists'):
+        dists = config.get(dist, 'dists').split()
+    else:
+        dists = [dist]
     components = config.get(dist, 'components').split()
 
     def seed_packages(germinator_method, structure, seed_name):
@@ -209,7 +214,9 @@ def main(argv):
             universal_newlines=True)
         (debootstrap_stdout, debootstrap_stderr) = debootstrap.communicate()
         if debootstrap.returncode != 0:
-            error_exit('Unable to retrieve package list from debootstrap; stdout: %s\nstderr: %s' % (debootstrap_stdout, debootstrap_stderr))
+            error_exit('Unable to retrieve package list from debootstrap; '
+                       'stdout: %s\nstderr: %s' %
+                       (debootstrap_stdout, debootstrap_stderr))
 
         # sometimes debootstrap gives empty packages / multiple separators
         packages = [pkg for pkg in debootstrap_stdout.split() if pkg]
@@ -225,25 +232,23 @@ def main(argv):
                 ['dpkg', '--compare-versions',
                  debootstrap_version, 'ge', old_debootstrap_version])
             if failed:
-                error_exit('Installed debootstrap is older than in the previous version! (%s < %s)' % (
-                    debootstrap_version,
-                    old_debootstrap_version
-                    ))
+                error_exit('Installed debootstrap is older than in the '
+                           'previous version! (%s < %s)' %
+                           (debootstrap_version, old_debootstrap_version))
 
     def update_debootstrap_version():
         with open(debootstrap_version_file, 'w') as debootstrap:
             debootstrap.write(get_debootstrap_version() + '\n')
 
     def format_changes(items):
-        by_arch = {}
-        for (pkg, arch) in items:
-            by_arch.setdefault(pkg, [])
-            by_arch[pkg].append(arch)
-        all_pkgs = sorted(by_arch.keys())
+        by_arch = defaultdict(set)
+        for pkg, arch in items:
+            by_arch[pkg].add(arch)
+        all_pkgs = sorted(by_arch)
         chunks = []
         for pkg in all_pkgs:
             arches = by_arch[pkg]
-            if set(architectures) - set(arches):
+            if set(architectures) - arches:
                 # only some architectures
                 chunks.append('%s [%s]' % (pkg, ' '.join(sorted(arches))))
             else:
@@ -255,15 +260,15 @@ def main(argv):
 
     check_debootstrap_version()
 
-    additions = {}
-    removals = {}
-    moves = {}
+    additions = defaultdict(list)
+    removals = defaultdict(list)
+    moves = defaultdict(list)
     metapackage_map = {}
     for architecture in architectures:
         print("[%s] Downloading available package lists..." % architecture)
         germinator = Germinator(architecture)
         archive = germinate.archive.TagFile(
-            [dist], components, architecture,
+            dists, components, architecture,
             archive_base[architecture], source_mirrors=archive_base_default,
             cleanup=True)
         germinator.parse_archive(archive)
@@ -298,7 +303,8 @@ def main(argv):
                 if package == meta_name:
                     print("%s/%s: Skipping package %s (metapackage)" %
                           (seed_name, architecture, package))
-                elif seed_name == 'minimal' and package not in debootstrap_base:
+                elif (seed_name == 'minimal' and
+                      package not in debootstrap_base):
                     print("%s/%s: Skipping package %s (package not in "
                           "debootstrap)" % (seed_name, architecture, package))
                 elif germinator.is_essential(package):
@@ -335,31 +341,29 @@ def main(argv):
                 options.outdir, '%s-%s' % (seed_name_recommends, architecture))
             if os.path.exists(output_recommends_filename):
                 with open(output_recommends_filename) as output:
-                    old_recommends_list = set(map(str.strip, output.readlines()))
-                os.rename(output_recommends_filename, output_recommends_filename + '.old')
+                    old_recommends_list = set(
+                        map(str.strip, output.readlines()))
+                os.rename(
+                    output_recommends_filename,
+                    output_recommends_filename + '.old')
 
             with open(output_recommends_filename, 'w') as output:
                 for package in new_recommends_list:
                     output.write(package)
                     output.write('\n')
 
-
             # Calculate deltas
-            merged = {}
-            recommends_merged = {}
+            merged = defaultdict(int)
+            recommends_merged = defaultdict(int)
             if old_list is not None:
                 for package in new_list:
-                    merged.setdefault(package, 0)
                     merged[package] += 1
                 for package in old_list:
-                    merged.setdefault(package, 0)
                     merged[package] -= 1
             if old_recommends_list is not None:
                 for package in new_recommends_list:
-                    recommends_merged.setdefault(package, 0)
                     recommends_merged[package] += 1
                 for package in old_recommends_list:
-                    recommends_merged.setdefault(package, 0)
                     recommends_merged[package] -= 1
 
             mergeditems = sorted(merged.items())
@@ -367,31 +371,25 @@ def main(argv):
                 #print(package, value)
                 if value == 1:
                     if recommends_merged.get(package, 0) == -1:
-                        moves.setdefault(package,[])
                         moves[package].append([seed_name, architecture])
                         recommends_merged[package] += 1
                     else:
-                        additions.setdefault(package,[])
                         additions[package].append([seed_name, architecture])
                 elif value == -1:
                     if recommends_merged.get(package, 0) == 1:
-                        moves.setdefault(package,[])
                         moves[package].append([seed_name_recommends,
                                                architecture])
                         recommends_merged[package] -= 1
                     else:
-                        removals.setdefault(package,[])
                         removals[package].append([seed_name, architecture])
 
             mergedrecitems = sorted(recommends_merged.items())
             for package, value in mergedrecitems:
                 #print(package, value)
                 if value == 1:
-                    additions.setdefault(package,[])
                     additions[package].append([seed_name_recommends,
                                                architecture])
                 elif value == -1:
-                    removals.setdefault(package,[])
                     removals[package].append([seed_name_recommends,
                                               architecture])
 
@@ -414,13 +412,13 @@ def main(argv):
         else:
             subprocess.check_call(['dch', '-i', 'Refreshed dependencies'])
         changes = []
-        for package in sorted(additions.keys()):
+        for package in sorted(additions):
             changes.append('Added %s to %s' %
                            (package, format_changes(additions[package])))
-        for package in sorted(removals.keys()):
+        for package in sorted(removals):
             changes.append('Removed %s from %s' %
                            (package, format_changes(removals[package])))
-        for package in sorted(moves.keys()):
+        for package in sorted(moves):
             # TODO: We should really list where it moved from as well, but
             # that gets wordy very quickly, and at the moment this is only
             # implemented for depends->recommends or vice versa. In future,
